@@ -67,7 +67,9 @@ def _read_file(  # pylint: disable=missing-return-doc
     return _format_data(_read_pandas(fnames, *args, **kwargs))
 
 
-def _read_pandas(fname: str, *args: Any, **kwargs: Any) -> pd.DataFrame:
+def _read_pandas(
+    fname: str, *args: Any, lowercase_cols=False, **kwargs: Any
+) -> pd.DataFrame:
     """
     Read a file and return a :class:`pd.DataFrame`.
 
@@ -75,6 +77,8 @@ def _read_pandas(fname: str, *args: Any, **kwargs: Any) -> pd.DataFrame:
     ----------
     fname
         Path from which to read data
+    lowercase_cols
+        If True, convert the column names of the file to lowercase
     *args
         Passed to :func:`pd.read_csv` if :obj:`fname` ends with '.csv', otherwise passed
         to :func:`pd.read_excel`.
@@ -102,6 +106,8 @@ def _read_pandas(fname: str, *args: Any, **kwargs: Any) -> pd.DataFrame:
             kwargs["sheet_name"] = "data"
         df = pd.read_excel(fname, *args, **kwargs)
 
+    if lowercase_cols:
+        df.columns = [c.lower() for c in df.columns]
     return df
 
 
@@ -356,9 +362,9 @@ class ScmRun:  # pylint: disable=too-many-public-methods
         Raises
         ------
         ValueError
-            If metadata for ['model', 'scenario', 'region', 'variable', 'unit'] is not
-            found. A :class:`ValueError` is also raised if you try to load from multiple
-            files at once. If you wish to do this, please use :func:`df_append` instead.
+            * If metadata for ['model', 'scenario', 'region', 'variable', 'unit'] is not found.
+            * If you try to load from multiple files at once. If you wish to do this, please use :func:`scmdata.run.run_append` instead.
+            * Not specifying :obj`index` and :obj`columns` if :obj`data` is a :obj`numpy.ndarray`
 
         TypeError
             Timeseries cannot be read from :obj:`data`
@@ -376,6 +382,12 @@ class ScmRun:  # pylint: disable=too-many-public-methods
         columns: Optional[Dict[str, list]] = None,
         **kwargs: Any,
     ):
+        if isinstance(data, np.ndarray):
+            if columns is None:
+                raise ValueError("`columns` argument is required")
+            if index is None:
+                raise ValueError("`index` argument is required")
+
         if columns is not None:
             (_df, _meta) = _from_ts(data, index=index, **columns)
         elif isinstance(data, ScmDataFrame):
@@ -800,7 +812,7 @@ class ScmRun:  # pylint: disable=too-many-public-methods
         bool
             If :obj:`ScmRun` is empty, return ``True``, if not return ``False``
         """
-        return np.equal(len(self._ts), 0)
+        return np.equal(len(self), 0)
 
     @property
     def meta(self) -> pd.DataFrame:
@@ -826,6 +838,7 @@ class ScmRun:  # pylint: disable=too-many-public-methods
         keep: bool = True,
         inplace: bool = False,
         has_nan: bool = True,
+        log_if_empty: bool = True,
         **kwargs: Any,
     ):
         """
@@ -880,6 +893,9 @@ class ScmRun:  # pylint: disable=too-many-public-methods
             in a string column which contains ;class:`np.nan` will result in a
             :class:`TypeError`.
 
+        log_if_empty
+            If ``True``, log a warning level message if the result is empty.
+
         **kwargs
             Argument names are keys with which to filter, values are used to do the
             filtering. Filtering can be done on:
@@ -941,7 +957,7 @@ class ScmRun:  # pylint: disable=too-many-public-methods
             ret._ts = [ts[_keep_times] for ts in ret._ts]
             ret["time"] = self.time_points.values[_keep_times]
 
-        if len(ret) == 0:
+        if log_if_empty and ret.empty:
             _logger.warning("Filtered ScmRun is empty!")
 
         if not inplace:
@@ -1494,7 +1510,7 @@ class ScmRun:  # pylint: disable=too-many-public-methods
             ret["unit_context"] = None
 
         to_convert = ret.filter(**kwargs)
-        to_not_convert = ret.filter(**kwargs, keep=False)
+        to_not_convert = ret.filter(**kwargs, keep=False, log_if_empty=False)
 
         def apply_units(group):
             orig_unit = group.get_unique_meta("unit", no_duplicates=True)
@@ -1509,7 +1525,7 @@ class ScmRun:  # pylint: disable=too-many-public-methods
 
         ret = to_convert.groupby("unit").map(apply_units)
 
-        ret = df_append([ret, to_not_convert], inplace=inplace)
+        ret = run_append([ret, to_not_convert], inplace=inplace)
         if not inplace:
             return ret
 
@@ -1566,7 +1582,7 @@ class ScmRun:  # pylint: disable=too-many-public-methods
         """
         Append additional data to the current dataframe.
 
-        For details, see :func:`df_append`.
+        For details, see :func:`run_append`.
 
         Parameters
         ----------
@@ -1595,7 +1611,7 @@ class ScmRun:  # pylint: disable=too-many-public-methods
         if not isinstance(other, ScmRun):
             other = self.__class__(other, **kwargs)
 
-        return df_append([self, other], inplace=inplace, duplicate_msg=duplicate_msg)
+        return run_append([self, other], inplace=inplace, duplicate_msg=duplicate_msg)
 
     def to_iamdataframe(self) -> LongDatetimeIamDataFrame:  # pragma: no cover
         """
@@ -1706,17 +1722,64 @@ class ScmRun:  # pylint: disable=too-many-public-methods
             return ScmRun(data, index=index, columns=meta)
 
 
-def df_append(
+def df_append(*args, **kwargs):
+    """
+    Append together many objects.
+
+    When appending many objects, it may be more efficient to call this routine once with
+    a list of :class:`ScmRun`'s, than using :func:`ScmRun.append` multiple times.
+
+    If timeseries with duplicate metadata are found, the timeseries are appended and values
+    falling on the same timestep are averaged if :obj:`duplicate_msg` is not "return". If
+    :obj:`duplicate_msg` is "return", then the result will contain the duplicated timeseries
+    for further inspection.
+
+    .. deprecated:: 0.5.0
+        :func:`df_append` will be removed in scmdata v0.6.0, it is replaced by :func:`scmdata.run.run_append`.
+    """
+    warnings.warn(
+        "scmdata.run.df_append has been deprecated and will be removed in v0.6.0. Use the scmdata.run.run_append class instead",
+        DeprecationWarning,
+        2,
+    )
+    return run_append(*args, **kwargs)
+
+
+def run_append(
     runs, inplace: bool = False, duplicate_msg: Union[str, bool] = "warn",
 ):
     """
     Append together many objects.
 
     When appending many objects, it may be more efficient to call this routine once with
-    a list of :class:`ScmRun`'s, than using :func:`ScmRun.append` multiple times. If
-    timeseries with duplicate metadata are found, the timeseries are appended and values
-    falling on the same timestep are averaged (this behaviour can be adjusted with the
-    :obj:`duplicate_msg` arguments).
+    a list of :class:`ScmRun`'s, than using :func:`ScmRun.append` multiple times.
+
+    If timeseries with duplicate metadata are found, the timeseries are appended and values
+    falling on the same timestep are averaged if :obj:`duplicate_msg` is not "return". If
+    :obj:`duplicate_msg` is "return", then the result will contain the duplicated timeseries
+    for further inspection.
+
+    .. code:: python
+
+        >>> res = base.append(other, duplicate_msg="return")
+        <scmdata.ScmRun (timeseries: 5, timepoints: 3)>
+        Time:
+            Start: 2005-01-01T00:00:00
+            End: 2015-06-12T00:00:00
+        Meta:
+                  scenario             variable  model climate_model region   unit
+            0   a_scenario       Primary Energy  a_iam       a_model  World  EJ/yr
+            1   a_scenario  Primary Energy|Coal  a_iam       a_model  World  EJ/yr
+            2  a_scenario2       Primary Energy  a_iam       a_model  World  EJ/yr
+            3  a_scenario3       Primary Energy  a_iam       a_model  World  EJ/yr
+            4   a_scenario       Primary Energy  a_iam       a_model  World  EJ/yr
+        >>> ts = res.timeseries(check_duplicated=False)
+        >>> ts[ts.index.duplicated(keep=False)]
+        time                                                        2005-01-01  ...  2015-06-12
+        scenario   variable       model climate_model region unit               ...
+        a_scenario Primary Energy a_iam a_model       World  EJ/yr         1.0  ...         7.0
+                                                             EJ/yr        -1.0  ...         1.0
+
 
     Parameters
     ----------
@@ -1730,15 +1793,14 @@ def df_append(
 
     duplicate_msg
         If "warn", raise a warning if duplicate data is detected. If "return", return
-        the joint dataframe (including duplicate timeseries) so the user can inspect
+        the joint :obj`ScmRun` (including duplicate timeseries) so the user can inspect
         further. If ``False``, take the average and do not raise a warning.
 
     Returns
     -------
     :obj:`ScmRun`
         If not :obj:`inplace`, the return value is the object containing the merged
-        data. The resultant class will be determined by the type of the first object. If
-        ``duplicate_msg == "return"``, a `pd.DataFrame` will be returned instead.
+        data. The resultant class will be determined by the type of the first object.
 
     Raises
     ------
@@ -1802,16 +1864,15 @@ def _handle_potential_duplicates_in_append(data, duplicate_msg):
     if duplicate_msg == "warn":
         warn_msg = (
             "Duplicate time points detected, the output will be the average of "
-            "the duplicates. Set `duplicate_msg='return'` to examine the joint "
-            "timeseries (the duplicates can be found by looking at "
-            "`res[res.index.duplicated(keep=False)].sort_index()`. Set "
-            "`duplicate_msg=False` to silence this message."
+            "the duplicates.  Set `duplicate_msg=False` to silence this message."
         )
         warnings.warn(warn_msg)
         return None
 
     if duplicate_msg == "return":
-        warnings.warn("returning a `pd.DataFrame`, not an `ScmRun`")
+        warnings.warn(
+            "Result contains overlapping data values with non unique metadata"
+        )
         return data
 
     raise ValueError("Unrecognised value for duplicate_msg")
